@@ -1,4 +1,4 @@
-# Copyright (C) 2014-2017 New York University
+# Copyright (C) 2014 New York University
 # This file is part of ReproZip which is released under the Revised BSD License
 # See file LICENSE for full license details.
 
@@ -35,6 +35,7 @@ import sys
 import tarfile
 import usagestats
 import yaml
+import zipfile
 
 from .utils import iteritems, itervalues, unicode_, stderr, UniqueNames, \
     escape, optional_return_type, isodatetime, hsize, join_root, copyfile
@@ -48,6 +49,7 @@ FILE_WRITE = 0x02
 FILE_WDIR = 0x04
 FILE_STAT = 0x08
 FILE_LINK = 0x10
+FILE_SOCKET = 0x20
 
 
 class File(object):
@@ -128,11 +130,27 @@ class Package(object):
 class RPZPack(object):
     """Encapsulates operations on the RPZ pack format.
     """
+    data = zip = tar = None
+
     def __init__(self, pack):
         self.pack = Path(pack)
 
-        self.tar = tarfile.open(str(self.pack), 'r:*')
-        f = self.tar.extractfile('METADATA/version')
+        if self._open_tar():
+            pass
+        elif self._open_zip():
+            pass
+        else:
+            raise ValueError("File doesn't appear to be an RPZ pack")
+
+    def _open_tar(self):
+        try:
+            self.tar = tarfile.open(str(self.pack), 'r:*')
+        except tarfile.TarError:
+            return False
+        try:
+            f = self.tar.extractfile('METADATA/version')
+        except KeyError:
+            raise ValueError("Invalid ReproZip file")
         version = f.read()
         f.close()
         if version.startswith(b'REPROZIP VERSION '):
@@ -148,7 +166,7 @@ class RPZPack(object):
                     "Unknown format version %r (maybe you should upgrade "
                     "reprounzip? I only know versions 1 and 2" % version)
         else:
-            raise ValueError("File doesn't appear to be a RPZ pack")
+            raise ValueError("File doesn't appear to be an RPZ pack")
 
         if self.version == 1:
             self.data = self.tar
@@ -158,6 +176,51 @@ class RPZPack(object):
                 mode='r:*')
         else:
             assert False
+        return True
+
+    def _open_zip(self):
+        try:
+            self.zip = zipfile.ZipFile(str(self.pack))
+        except zipfile.BadZipfile:
+            return False
+        try:
+            f = self.zip.open('METADATA/version')
+        except KeyError:
+            raise ValueError("Invalid ReproZip file")
+        version = f.read()
+        f.close()
+        if version.startswith(b'REPROZIP VERSION '):
+            try:
+                version = int(version[17:].rstrip())
+            except ValueError:
+                version = None
+            if version == 1:
+                raise ValueError("Format version 1 is not accepted for ZIP")
+            elif version == 2:
+                self.version = 2
+                self.data_prefix = PosixPath(b'DATA')
+            else:
+                raise ValueError(
+                    "Unknown format version %r (maybe you should upgrade "
+                    "reprounzip? I only know versions 1 and 2" % version)
+        else:
+            raise ValueError("File doesn't appear to be an RPZ pack")
+
+        if sys.version_info < (3, 7):
+            # zip.open() doesn't return a seekable file object before 3.6
+            # Extract to a temporary file instead
+            fd, temporary_data = Path.tempfile(
+                prefix='reprounzip_data_',
+                suffix='.zip',
+            )
+            os.close(fd)
+            self._extract_file('DATA.tar.gz', temporary_data)
+            self.data = tarfile.open(str(temporary_data), mode='r:*')
+            atexit.register(os.remove, temporary_data.path)
+        else:
+            self.data = tarfile.open(fileobj=self.zip.open('DATA.tar.gz'),
+                                     mode='r:*')
+        return True
 
     def remove_data_prefix(self, path):
         if not isinstance(path, PosixPath):
@@ -170,26 +233,35 @@ class RPZPack(object):
     def open_config(self):
         """Gets the configuration file.
         """
-        return self.tar.extractfile('METADATA/config.yml')
+        if self.tar is not None:
+            return self.tar.extractfile('METADATA/config.yml')
+        else:
+            return self.zip.open('METADATA/config.yml')
 
     def extract_config(self, target):
         """Extracts the config to the specified path.
 
         It is up to the caller to remove that file once done.
         """
-        self._extract_file(self.tar.getmember('METADATA/config.yml'),
-                           target)
+        self._extract_file('METADATA/config.yml', target)
 
-    def _extract_file(self, member, target):
-        member = copy.copy(member)
-        member.name = str(target.components[-1])
-        self.tar.extract(member,
-                         path=str(Path.cwd() / target.parent))
+    def _extract_file(self, name, target):
+        if self.tar is not None:
+            member = copy.copy(self.tar.getmember(name))
+            member.name = str(target.components[-1])
+            self.tar.extract(member, path=str(Path.cwd() / target.parent))
+        else:
+            member = copy.copy(self.zip.getinfo(name))
+            member.filename = str(target.components[-1])
+            self.zip.extract(member, path=str(Path.cwd() / target.parent))
         target.chmod(0o644)
         assert target.is_file()
 
-    def _extract_file_gz(self, member, target):
-        f_in = self.tar.extractfile(member)
+    def _extract_file_gz(self, name, target):
+        if self.tar is not None:
+            f_in = self.tar.extractfile(name)
+        else:
+            f_in = self.zip.open(name)
         f_in_gz = gzip.open(f_in)
         f_out = target.open('wb')
         try:
@@ -203,6 +275,7 @@ class RPZPack(object):
             f_out.close()
             f_in_gz.close()
             f_in.close()
+        target.chmod(0o644)
 
     @contextlib.contextmanager
     def with_config(self):
@@ -220,25 +293,24 @@ class RPZPack(object):
         It is up to the caller to remove that file once done.
         """
         target = Path(target)
-        if self.version == 1:
-            member = self.tar.getmember('METADATA/trace.sqlite3')
-            self._extract_file(member, target)
-        elif self.version == 2:
+        if self.version == 2:
             try:
-                member = self.tar.getmember('METADATA/trace.sqlite3.gz')
+                if self.tar is not None:
+                    self.tar.getmember('METADATA/trace.sqlite3.gz')
+                else:
+                    self.zip.getinfo('METADATA/trace.sqlite3.gz')
             except KeyError:
                 pass
             else:
-                self._extract_file_gz(member, target)
+                self._extract_file_gz('METADATA/trace.sqlite3.gz', target)
                 return
-            member = self.tar.getmember('METADATA/trace.sqlite3')
-            self._extract_file(member, target)
-        else:
+        elif self.version != 2:
             assert False
+        self._extract_file('METADATA/trace.sqlite3', target)
 
     @contextlib.contextmanager
     def with_trace(self):
-        """Context manager that extracts the trace database to a temporary file.
+        """Context manager extracting the trace database to a temporary file.
         """
         fd, tmp = Path.tempfile(prefix='reprounzip_')
         os.close(fd)
@@ -277,24 +349,62 @@ class RPZPack(object):
 
         The members must come from get_data().
         """
+        # Check for CVE-2007-4559
+        abs_root = root.absolute()
+        for member in members:
+            member_path = (root / member.name).absolute()
+            if not member_path.lies_under(abs_root):
+                raise ValueError("Invalid path in data tar")
+
         self.data.extractall(str(root), members)
 
     def copy_data_tar(self, target):
         """Copies the file in which the data lies to the specified destination.
         """
-        if self.version == 1:
-            self.pack.copyfile(target)
-        elif self.version == 2:
+        if self.tar is not None:
+            if self.version == 1:
+                self.pack.copyfile(target)
+            elif self.version == 2:
+                with target.open('wb') as fp:
+                    data = self.tar.extractfile('DATA.tar.gz')
+                    copyfile(data, fp)
+                    data.close()
+        else:
             with target.open('wb') as fp:
-                data = self.tar.extractfile('DATA.tar.gz')
+                data = self.zip.open('DATA.tar.gz')
                 copyfile(data, fp)
                 data.close()
 
+    def extensions(self):
+        """Get a list of extensions present in this pack.
+        """
+        extensions = set()
+        if self.tar is not None:
+            for m in self.tar.getmembers():
+                if m.name.startswith('EXTENSIONS/'):
+                    name = m.name[11:]
+                    if '/' in name:
+                        name = name[:name.index('/')]
+                    if name:
+                        extensions.add(name)
+        else:
+            for m in self.zip.infolist():
+                if m.filename.startswith('EXTENSIONS/'):
+                    name = m.filename[11:]
+                    if '/' in name:
+                        name = name[:name.index('/')]
+                    if name:
+                        extensions.add(name)
+        return extensions
+
     def close(self):
         if self.data is not self.tar:
             self.data.close()
-        self.tar.close()
-        self.data = self.tar = None
+        if self.tar is not None:
+            self.tar.close()
+        elif self.zip is not None:
+            self.zip.close()
+        self.data = self.zip = self.tar = None
 
 
 class InvalidConfig(ValueError):
@@ -374,6 +484,16 @@ def load_iofiles(config, runs):
         path = PosixPath(f['path'])
         readers = sorted(f.get('read_by_runs', []))
         writers = sorted(f.get('written_by_runs', []))
+        if (
+            not isinstance(readers, (tuple, list))
+            or not all(isinstance(e, int) for e in readers)
+        ):
+            raise InvalidConfig("read_by_runs should be a list of integers")
+        if (
+            not isinstance(writers, (tuple, list))
+            or not all(isinstance(e, int) for e in writers)
+        ):
+            raise InvalidConfig("written_by_runs should be a list of integers")
         if name in files:
             if files[name].path != path:
                 old_name, name = name, uniquenames(name)
@@ -589,7 +709,7 @@ other_files:
 # If you want to include additional files in the pack, you can list additional
 # patterns of files that will be included
 additional_patterns:
-# Example:
+# Examples:
 #  - /etc/apache2/**  # Everything under apache2/
 #  - /var/log/apache2/*.log  # Log files directly under apache2/
 #  - /var/lib/lxc/*/rootfs/home/**/*.py  # All Python files of all users in
@@ -617,7 +737,7 @@ def setup_logging(tag, verbosity):
     file_level = logging.INFO
     min_level = min(console_level, file_level)
 
-    # Create formatter, with same format as C extension
+    # Create formatter
     fmt = "[%s] %%(asctime)s %%(levelname)s: %%(message)s" % tag
     formatter = LoggingDateFormatter(fmt)
 
@@ -656,6 +776,8 @@ def setup_logging(tag, verbosity):
                 (datetime.now().strftime("%Y-%m-%d"), sys.argv),
                 None))
 
+    logging.getLogger('urllib3').setLevel(logging.INFO)
+
 
 _usage_report = None
 
@@ -771,4 +893,24 @@ YIKRjGU7Of3CycOCbaT50VZHhEd5GS2Lvg41ngxtsE8JKnvPuim92dnCutD0beV+
 DCfXxuMMg3wo5pbqG+MvTdECaLwt14zWU259z8JX0BoeVG32kHlt2eUpm5PCfxqc
 dYuwZmAXksp0T0cWo0DnjJKRGQ==
 -----END CERTIFICATE-----
+-----BEGIN CERTIFICATE-----
+MIIDRDCCAiygAwIBAgIUXaa8P7qR4c0P51hCDIqj4GUbG/owDQYJKoZIhvcNAQEL
+BQAwEzERMA8GA1UEAwwIUmVwcm9aaXAwIBcNMjEwNDI5MjEwNTUzWhgPMjEyMTA0
+MjkyMTA1NTNaMBMxETAPBgNVBAMMCFJlcHJvWmlwMIIBIjANBgkqhkiG9w0BAQEF
+AAOCAQ8AMIIBCgKCAQEA3udPriZ8kziQE+OyLVozJFDSZTe8RLlpFsu/ZQjSnIh1
+TsENMMu1lwv0GVEpT/EbtD5ORtZzwYQ7Vuh+IO4TQDhA5KvyJD2gZW8hE4txkkQd
+yI5vSj0iiViA80tKB7FSDLsvz9iiDxShYHJI947gswbaLmampHIXD/Rjjs7+hmL5
+RRS5NL8vCp2/2QVj5wnJupa5O2l2T1M6S/SyFcAgBMM/FhDsaA/yf4NPcOG6gFuO
+b5mYz2ERSf4v9mRL+G3r6YULYGZWS5ThY0QoZ0lYt2nlthzwfftazrJ9+yfYBkoJ
+K6Ug8UGtyOb5m3mK00c4wS7/wzuGgLMszkE0nE9SfwIDAQABo4GNMIGKMB0GA1Ud
+DgQWBBSqrIPVnO5vkHj9ImGvOr38r4rcNjBOBgNVHSMERzBFgBSqrIPVnO5vkHj9
+ImGvOr38r4rcNqEXpBUwEzERMA8GA1UEAwwIUmVwcm9aaXCCFF2mvD+6keHND+dY
+QgyKo+BlGxv6MAwGA1UdEwQFMAMBAf8wCwYDVR0PBAQDAgEGMA0GCSqGSIb3DQEB
+CwUAA4IBAQC2g8yX1c5JutH/qAKUVvqSwP2KBm3IyOjdbN7cvnwn0gMkwEj88j7p
+dKhfO0Kfp/N4iKj1YK7PBXfrdlYhxINSbfPSVS3A9XWi8pJwiwgBfjrrACRMhBsv
+HAQPnkXnaEJrQm//k8s4etT25JYaPgXS8t+dgVS0iqonYlpCB1XkE0gw1kLNCW5F
+1SimUehJ5bZrJYGgo6kp44F12kPMzNHvk50Sf2p3nm2d9/BNbbJQxUBKt9n+i6Ir
+xGGDWfg5F+BLKURWkoGBnnLPqkRxlkaGvk6QpIAfD1h99fTyuWUno3+NoQ7hS952
+yWbmqwbavTIyG+D+kfhbGFEdRxLF5BeK
+-----END CERTIFICATE-----
 '''
