@@ -1,4 +1,4 @@
-# Copyright (C) 2014-2017 New York University
+# Copyright (C) 2014 New York University
 # This file is part of ReproZip which is released under the Revised BSD License
 # See file LICENSE for full license details.
 
@@ -29,9 +29,10 @@ from reprounzip.common import setup_logging, \
     submit_usage_report, record_usage
 from reprounzip import signals
 from reprounzip.unpackers.common import UsageError
+from reprounzip.utils import stderr
 
 
-__version__ = '1.0.16'
+__version__ = '1.3'
 
 
 logger = logging.getLogger('reprounzip')
@@ -79,7 +80,10 @@ def main():
     """Entry point when called on the command-line.
     """
     # Locale
-    locale.setlocale(locale.LC_ALL, '')
+    try:
+        locale.setlocale(locale.LC_ALL, '')
+    except locale.Error as e:
+        stderr.write("Couldn't set locale: %s\n" % e)
 
     # Parses command-line
 
@@ -96,7 +100,7 @@ def main():
         description="reprounzip is the ReproZip component responsible for "
                     "unpacking and reproducing an experiment previously "
                     "packed with reprozip",
-        epilog="Please report issues to reprozip-users@vgc.poly.edu")
+        epilog="Please report issues to reprozip@nyu.edu")
     add_options(parser)
     parser.add_argument('-v', '--verbose', action='count', default=1,
                         dest='verbosity',
