@@ -1,4 +1,4 @@
-# Copyright (C) 2014-2017 New York University
+# Copyright (C) 2014 New York University
 # This file is part of ReproZip which is released under the Revised BSD License
 # See file LICENSE for full license details.
 
@@ -123,6 +123,9 @@ def get_package_info(pack, read_data=False):
                'write_runs': iofile.write_runs}
         for name, iofile in iteritems(inputs_outputs)}
 
+    rpz_pack = RPZPack(pack)
+    information['extensions'] = sorted(rpz_pack.extensions())
+
     # Unpacker compatibility
     unpacker_status = {}
     for name, upk in iteritems(unpackers):
@@ -215,6 +218,12 @@ def _print_package_info(pack, info, verbosity=1):
                     t.append("out")
                 print("    %s (%s): %s" % (name, ' '.join(t), f['path']))
 
+    extensions = info.get('extensions')
+    if extensions:
+        print("\n----- Extensions -----")
+        for name in extensions:
+            print(name)
+
     unpacker_status = info.get('unpacker_status')
     if unpacker_status:
         print("\n----- Unpackers -----")
