@@ -1,4 +1,4 @@
-# Copyright (C) 2014-2017 New York University
+# Copyright (C) 2014 New York University
 # This file is part of ReproZip which is released under the Revised BSD License
 # See file LICENSE for full license details.
 
@@ -100,6 +100,12 @@ _bundled_parameters = {
         "i686": "https://github.com/remram44/static-sudo/releases/download/"
                 "current/rpzsudo-i686"
     },
+    "rpztar_url": {
+        "x86_64": "https://github.com/remram44/rpztar/releases/download/"
+                  "v1/rpztar-x86_64",
+        "i686": "https://github.com/remram44/rpztar/releases/download/"
+                "v1/rpztar-i686"
+    },
     "docker_images": {
         "default": "debian",
         "images": {
@@ -164,12 +170,24 @@ _bundled_parameters = {
                         "distribution": "ubuntu",
                         "image": "ubuntu:18.04",
                         "name": "Ubuntu 18.04 'Bionic'"
+                    },
+                    {
+                        "version": "^18\\.10$",
+                        "distribution": "ubuntu",
+                        "image": "ubuntu:18.10",
+                        "name": "Ubuntu 18.10 'Cosmic'"
+                    },
+                    {
+                        "version": "^19\\.04$",
+                        "distribution": "ubuntu",
+                        "image": "ubuntu:19.04",
+                        "name": "Ubuntu 19.04 'Disco'"
                     }
                 ],
                 "default": {
                     "distribution": "ubuntu",
-                    "image": "ubuntu:16.04",
-                    "name": "Ubuntu 16.04 'Xenial'"
+                    "image": "ubuntu:19.04",
+                    "name": "Ubuntu 19.04 'Disco'"
                 }
             },
             "debian": {
@@ -340,8 +358,8 @@ _bundled_parameters = {
                         "version": "^15\\.04$",
                         "distribution": "ubuntu",
                         "architectures": {
-                            "i686": "ubuntu/vivid32",
-                            "x86_64": "ubuntu/vivid64"
+                            "i686": "bento/ubuntu-15.04-i386",
+                            "x86_64": "bento/ubuntu-15.04"
                         },
                         "name": "Ubuntu 15.04 'Vivid'"
                     },
@@ -349,8 +367,8 @@ _bundled_parameters = {
                         "version": "^15\\.10$",
                         "distribution": "ubuntu",
                         "architectures": {
-                            "i686": "ubuntu/wily32",
-                            "x86_64": "ubuntu/wily64"
+                            "i686": "bento/ubuntu-15.10-i386",
+                            "x86_64": "bento/ubuntu-15.10"
                         },
                         "name": "Ubuntu 15.10 'Wily'"
                     },
@@ -394,19 +412,58 @@ _bundled_parameters = {
                         "version": "^18\\.04$",
                         "distribution": "ubuntu",
                         "architectures": {
-                            "i686": "bento/ubuntu-18.04-i386",
                             "x86_64": "bento/ubuntu-18.04"
                         },
                         "name": "Ubuntu 18.04 'Bionic'"
+                    },
+                    {
+                        "version": "^18\\.10$",
+                        "distribution": "ubuntu",
+                        "architectures": {
+                            "x86_64": "bento/ubuntu-18.10"
+                        },
+                        "name": "Ubuntu 18.10 'Cosmic'"
+                    },
+                    {
+                        "version": "^19\\.04$",
+                        "distribution": "ubuntu",
+                        "architectures": {
+                            "x86_64": "bento/ubuntu-19.04"
+                        },
+                        "name": "Ubuntu 19.04 'Disco'"
+                    },
+                    {
+                        "version": "^19\\.10",
+                        "distribution": "ubuntu",
+                        "architectures": {
+                            "x86_64": "bento/ubuntu-19.10"
+                        },
+                        "name": "Ubuntu 19.10 'Eoan'"
+                    },
+                    {
+                        "version": "^20\\.04$",
+                        "distribution": "ubuntu",
+                        "architectures": {
+                            "x86_64": "bento/ubuntu-20.04"
+                        },
+                        "name": "Ubuntu 20.04 'Focal'"
+                    },
+                    {
+                        "version": "^20\\.10",
+                        "distribution": "ubuntu",
+                        "architectures": {
+                            "x86_64": "bento/ubuntu-20.10"
+                        },
+                        "name": "Ubuntu 20.10 'Groovy'"
                     }
                 ],
                 "default": {
                     "distribution": "ubuntu",
                     "architectures": {
-                        "i686": "bento/ubuntu-18.04-i386",
-                        "x86_64": "bento/ubuntu-18.04"
+                        "i686": "bento/ubuntu-17.04-i386",
+                        "x86_64": "bento/ubuntu-20.04"
                     },
-                    "name": "Ubuntu 18.04 'Bionic'"
+                    "name": "Ubuntu"
                 }
             },
             "debian": {
@@ -415,8 +472,8 @@ _bundled_parameters = {
                         "version": "^(7(\\.|$))|(wheezy)",
                         "distribution": "debian",
                         "architectures": {
-                            "i686": "remram/debian-7-i386",
-                            "x86_64": "remram/debian-7-amd64"
+                            "i686": "bento/debian-7.11-i386",
+                            "x86_64": "bento/debian-7"
                         },
                         "name": "Debian 7 'Wheezy'"
                     },
@@ -437,15 +494,24 @@ _bundled_parameters = {
                             "x86_64": "remram/debian-9-amd64"
                         },
                         "name": "Debian 9 'Stretch'"
+                    },
+                    {
+                        "version": "^(10(\\.|$))|(buster)",
+                        "distribution": "debian",
+                        "architectures": {
+                            "i686": "remram/debian-10-i386",
+                            "x86_64": "bento/debian-10"
+                        },
+                        "name": "Debian 10 'Buster'"
                     }
                 ],
                 "default": {
                     "distribution": "debian",
                     "architectures": {
-                        "i686": "remram/debian-8-i386",
-                        "x86_64": "remram/debian-8-amd64"
+                        "i686": "remram/debian-10-i386",
+                        "x86_64": "bento/debian-10"
                     },
-                    "name": "Debian 8 'Jessie'"
+                    "name": "Debian 10 'Buster'"
                 }
             },
             "centos": {
@@ -463,27 +529,36 @@ _bundled_parameters = {
                         "version": "^6\\.",
                         "distribution": "centos",
                         "architectures": {
-                            "i686": "bento/centos-6.7-i386",
-                            "x86_64": "bento/centos-6.7"
+                            "i686": "bento/centos-6.10-i386",
+                            "x86_64": "bento/centos-6.10"
                         },
-                        "name": "CentOS 6.7"
+                        "name": "CentOS 6.10"
                     },
                     {
                         "version": "^7\\.",
                         "distribution": "centos",
                         "architectures": {
-                            "x86_64": "bento/centos-7.2"
+                            "i686": "remram/centos-7-i386",
+                            "x86_64": "bento/centos-7.6"
                         },
-                        "name": "CentOS 7.2"
+                        "name": "CentOS 7.6"
+                    },
+                    {
+                        "version": "^8\\.",
+                        "distribution": "centos",
+                        "architectures": {
+                            "x86_64": "bento/centos-8"
+                        },
+                        "name": "CentOS 8"
                     }
                 ],
                 "default": {
                     "distribution": "centos",
                     "architectures": {
-                        "i686": "bento/centos-6.7-i386",
-                        "x86_64": "bento/centos-6.7"
+                        "i686": "remram/centos-7-i386",
+                        "x86_64": "bento/centos-8"
                     },
-                    "name": "CentOS 6.7"
+                    "name": "CentOS"
                 }
             },
             "centos linux": {
@@ -501,27 +576,35 @@ _bundled_parameters = {
                         "version": "^6\\.",
                         "distribution": "centos",
                         "architectures": {
-                            "i686": "bento/centos-6.7-i386",
-                            "x86_64": "bento/centos-6.7"
+                            "i686": "bento/centos-6.10-i386",
+                            "x86_64": "bento/centos-6.10"
                         },
-                        "name": "CentOS 6.7"
+                        "name": "CentOS 6.10"
                     },
                     {
                         "version": "^7\\.",
                         "distribution": "centos",
                         "architectures": {
-                            "x86_64": "bento/centos-7.2"
+                            "x86_64": "bento/centos-7.6"
                         },
-                        "name": "CentOS 7.2"
+                        "name": "CentOS 7.6"
+                    },
+                    {
+                        "version": "^8\\.",
+                        "distribution": "centos",
+                        "architectures": {
+                            "x86_64": "bento/centos-8"
+                        },
+                        "name": "CentOS 8"
                     }
                 ],
                 "default": {
                     "distribution": "centos",
                     "architectures": {
-                        "i686": "bento/centos-6.7-i386",
-                        "x86_64": "bento/centos-6.7"
+                        "i686": "remram/centos-7-i386",
+                        "x86_64": "bento/centos-8"
                     },
-                    "name": "CentOS 6.7"
+                    "name": "CentOS"
                 }
             },
             "fedora": {
@@ -584,15 +667,55 @@ _bundled_parameters = {
                             "x86_64": "bento/fedora-28"
                         },
                         "name": "Fedora 28"
+                    },
+                    {
+                        "version": "^29$",
+                        "distribution": "fedora",
+                        "architectures": {
+                            "x86_64": "bento/fedora-29"
+                        },
+                        "name": "Fedora 29"
+                    },
+                    {
+                        "version": "^30",
+                        "distribution": "fedora",
+                        "architectures": {
+                            "x86_64": "bento/fedora-30"
+                        },
+                        "name": "Fedora 30"
+                    },
+                    {
+                        "version": "^31",
+                        "distribution": "fedora",
+                        "architectures": {
+                            "x86_64": "bento/fedora-31"
+                        },
+                        "name": "Fedora 31"
+                    },
+                    {
+                        "version": "^32",
+                        "distribution": "fedora",
+                        "architectures": {
+                            "x86_64": "bento/fedora-32"
+                        },
+                        "name": "Fedora 32"
+                    },
+                    {
+                        "version": "^33",
+                        "distribution": "fedora",
+                        "architectures": {
+                            "x86_64": "bento/fedora-33"
+                        },
+                        "name": "Fedora 33"
                     }
                 ],
                 "default": {
                     "distribution": "fedora",
                     "architectures": {
                         "i686": "remram/fedora-24-i386",
-                        "x86_64": "remram/fedora-24-amd64"
+                        "x86_64": "bento/fedora-33"
                     },
-                    "name": "Fedora 24"
+                    "name": "Fedora"
                 }
             }
         }
